import { CoreDaemon } from './core.js';
import { CoreWallet } from './wallet.js';
import { TxBytes, TxData } from '@scrow/tapscript';
import { BlockQuery, ClientConfig, MethodArgs, ScanAction, ScanObject, ScanResults, CoreConfig, CmdConfig, BlockData, BlockHeader, ScanOptions, TxResult, TxStatus } from '../types/index.js';
export declare class CoreClient {
    readonly _core: CoreDaemon;
    readonly _opt: CoreConfig;
    params: string[];
    _cache: [string, unknown];
    _faucet: CoreWallet | null;
    constructor(core: CoreDaemon, config?: Partial<ClientConfig>);
    get opt(): CoreConfig;
    get blocks(): Promise<number>;
    get chain_info(): Promise<Record<string, any>>;
    get core(): CoreDaemon;
    get wallets_loaded(): Promise<string[]>;
    get wallets_created(): Promise<string[]>;
    _debug(...msg: unknown[]): void;
    _log(...msg: unknown[]): void;
    cmd<T = Record<string, string>>(method: string, args?: MethodArgs, config?: Partial<CmdConfig>): Promise<T>;
    _get_block_data(query: BlockQuery, txdata?: boolean): Promise<BlockHeader>;
    get_block(query: BlockQuery): Promise<BlockData>;
    get_header(query: BlockQuery): Promise<BlockHeader>;
    scan_txout(action: ScanAction, ...desc: (string | ScanObject)[]): Promise<ScanResults>;
    mine_blocks(count?: number, addr?: string): Promise<Record<string, string>>;
    get_tx(txid: string): Promise<TxResult | null>;
    get_txout(txid: string, vout: number): Promise<{
        value: number;
        bestblock: string;
        confirmations: number;
        scriptPubKey: import("../types/tx.js").ScriptKey;
        coinbase: boolean;
    } | null>;
    get_utxos(opt: ScanOptions): Promise<{
        amount: number;
        txid: string;
        vout: number;
        desc: string;
        height: number;
        coinbase: boolean;
        scriptPubKey: string;
    }[]>;
    get_txout_status(txid: string, vout: number): Promise<{
        spent: boolean;
    } | null>;
    get_txinput(txid: string, vout: number): Promise<{
        txinput: import("@scrow/tapscript").TxPrevout;
        status: TxStatus;
    } | null>;
    load_wallet(name: string): Promise<CoreWallet>;
    load_wallets(...labels: string[]): Promise<Record<string, CoreWallet>>;
    publish_tx(txdata: TxBytes | TxData, confirm?: boolean): Promise<string>;
    set_time(timestamp?: number): Promise<void>;
}
//# sourceMappingURL=client.d.ts.map